@@ -4,7 +4,7 @@ package WebService::OpenSky;
 
 # ABSTRACT: Perl interface to the OpenSky Network API
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 use v5.20.0;
 use Moose;
 use WebService::OpenSky::Types qw(
@@ -23,6 +23,7 @@ use WebService::OpenSky::Types qw(
 );
 use WebService::OpenSky::Response::States;
 use WebService::OpenSky::Response::Flights;
+use WebService::OpenSky::Response::FlightTrack;
 use PerlX::Maybe;
 use Config::INI::Reader;
 use Carp qw( carp croak );
@@ -251,6 +252,19 @@ sub get_departures_by_airport ( $self, $airport, $begin, $end ) {
     );
 }
 
+sub get_track_by_aircraft ( $self, $icao24, $time ) {
+    if ( $time != 0 && ( time - $time ) > 2592 * 1e3 ) {
+        croak 'It is not possible to access flight tracks from more than 30 days in the past.';
+    }
+
+    my %params = ( icao24 => $icao24, time => $time );
+    return $self->_get_response(
+        route  => '/tracks/all',
+        params => \%params,
+        class  => 'WebService::OpenSky::Response::FlightTrack',
+    );
+}
+
 signature_for _get_response => (
     method => 1,
     named  => [
@@ -391,7 +405,7 @@ WebService::OpenSky - Perl interface to the OpenSky Network API
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -636,6 +650,18 @@ The first argument is the ICAO24 transponder address of the aircraft you want.
 
 Returns an instance of L<WebService::OpenSky::Response::Flights>.
 
+=head2 C<get_track_by_aircraft>
+
+	my $track = $api->get_track_by_aircraft( $icao24, $start );
+
+Adds support for the experimental L<GET
+/tracks|https://openskynetwork.github.io/opensky-api/rest.html#track-by-aircraft>
+endpoint. Returns an instance of
+L<WebService::OpenSky::Response::FlightTrack>.
+
+Per the OpenSky documentation, this endpoint is experimental and may be removed or simply
+not working at any time.
+
 =head2 C<limit_remaining>
 
     my $limit = $api->limit_remaining;
